@@ -13,7 +13,7 @@ public enum GridHeaderOperationId {
 		COLUMNDELETE("6"),
 		COLUMNTYPE("7"),
 		COLUMNFILTER("8"),
-		COLUMNEDIT("9"),
+		COLUMNBATCHREPLACE("9"),
 		ANNOTATIONADD("10"),
 		DUPLICATEDETECTION("11");		
 		
